# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

from dlrnapi_client.models.params_1 import Params1


class TestParams1(unittest.TestCase):
    """Params1 unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testParams1(self):
        """Test Params1 """
        model = Params1()
        expected = {'max_age': None, 'job_id': None, 'success': None,
                    'previous_job_id': None, 'sequential_mode': None,
                    'reporting_job_id': None, 'component': None}
        self.assertEqual(model.to_dict(), expected)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems


class CIAggVote(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, job_id=None, commit_hash=None, distro_hash=None,
                 aggregate_hash=None, url=None, timestamp=None,
                 in_progress=None, success=None, notes=None, component=None):
        """CIAggVote - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'job_id': 'str',
            'aggregate_hash': 'str',
            'url': 'str',
            'timestamp': 'int',
            'in_progress': 'bool',
            'success': 'bool',
            'notes': 'str',
        }

        self.attribute_map = {
            'job_id': 'job_id',
            'aggregate_hash': 'aggregate_hash',
            'url': 'url',
            'timestamp': 'timestamp',
            'in_progress': 'in_progress',
            'success': 'success',
            'notes': 'notes',
        }

        self._job_id = job_id
        self._aggregate_hash = aggregate_hash
        self._url = url
        self._timestamp = timestamp
        self._in_progress = in_progress
        self._success = success
        self._notes = notes

    @property
    def job_id(self):
        """Gets the job_id of this CIVote.

        name of the CI sending the vote

        :return: The job_id of this CIVote.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this CIVote.

        name of the CI sending the vote

        :param job_id: The job_id of this CIVote.
        :type: str
        """

        self._job_id = job_id

    @property
    def aggregate_hash(self):
        """Gets the aggregate_hash of this CIVote.

        aggregate_hash of tested repo

        :return: The aggregate_hash of this CIVote.
        :rtype: str
        """
        return self._aggregate_hash

    @aggregate_hash.setter
    def aggregate_hash(self, aggregate_hash):
        """Sets the aggregate_hash of this CIVote.

        aggregate_hash of tested repo

        :param aggregate_hash: The aggregate_hash of this CIVote.
        :type: str
        """

        self._aggregate_hash = aggregate_hash

    @property
    def url(self):
        """Gets the url of this CIVote.

        URL where to find additional information from the CI execution

        :return: The url of this CIVote.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CIVote.

        URL where to find additional information from the CI execution

        :param url: The url of this CIVote.
        :type: str
        """

        self._url = url

    @property
    def timestamp(self):
        """Gets the timestamp of this CIVote.

        Timestamp (in seconds since the epoch)

        :return: The timestamp of this CIVote.
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this CIVote.

        Timestamp (in seconds since the epoch)

        :param timestamp: The timestamp of this CIVote.
        :type: int
        """

        self._timestamp = timestamp

    @property
    def in_progress(self):
        """Gets the in_progress of this CIVote.

        is this CI job still in-progress?

        :return: The in_progress of this CIVote.
        :rtype: bool
        """
        return self._in_progress

    @in_progress.setter
    def in_progress(self, in_progress):
        """Sets the in_progress of this CIVote.

        is this CI job still in-progress?

        :param in_progress: The in_progress of this CIVote.
        :type: bool
        """

        self._in_progress = in_progress

    @property
    def success(self):
        """Gets the success of this CIVote.

        Was the CI execution successful?

        :return: The success of this CIVote.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this CIVote.

        Was the CI execution successful?

        :param success: The success of this CIVote.
        :type: bool
        """

        self._success = success

    @property
    def notes(self):
        """Gets the notes of this CIVote.

        additional notes

        :return: The notes of this CIVote.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this CIVote.

        additional notes

        :param notes: The notes of this CIVote.
        :type: str
        """

        self._notes = notes

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, CIVote):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

from dlrnapi_client.models.promotion_query import PromotionQuery


class TestPromotionQuery(unittest.TestCase):
    """Promotion unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPromotionQuery(self):
        """Test PromotionQuery """
        model = PromotionQuery()
        expected = {'promote_name': None, 'commit_hash': None,
                    'distro_hash': None, 'extended_hash': None,
                    'offset': None, 'limit': None, 'component': None,
                    'aggregate_hash': None}
        self.assertEqual(model.to_dict(), expected)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems


class MetricsRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, start_date=None, end_date=None, package_name=None):
        """MetricsRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_date': 'str',
            'end_date': 'str',
            'package_name': 'str',
        }

        self.attribute_map = {
            'start_date': 'start_date',
            'end_date': 'end_date',
            'package_name': 'package_name',
        }

        self._start_date = start_date
        self._end_date = end_date
        self._package_name = package_name

    @property
    def start_date(self):
        """Gets the start_date of this Metrics Request.

        start_date of the period to consider, in YYYY-MM-DD format.

        :return: The start_date of this Metrics Request.
        :rtype: str
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the commit_hash of this Promotion Query.

        start_date of the period to consider, in YYYY-MM-DD format.

        :param start_date: The start_date of this Metrics Request.
        :type: str
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Metrics Request.

        end_date of the period to consider, in YYYY-MM-DD format.

        :return: The end_date of this Metrics Request.
        :rtype: str
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the commit_hash of this Promotion Query.

        end_date of the period to consider, in YYYY-MM-DD format.

        :param end_date: The end_date of this Metrics Request.
        :type: str
        """

        self._end_date = end_date

    @property
    def package_name(self):
        """Gets the package_name of this Metrics Request.

        package_name to filter the query.

        :return: package_name to filter the query.
        :rtype: str
        """
        return self._package_name

    @package_name.setter
    def package_name(self, package_name):
        """Sets the commit_hash of this Promotion Query.

        package_name to filter the query.

        :param package_name: package_name to filter the query.
        :type: str
        """

        self._package_name = package_name

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, MetricsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other


class Metrics(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, succeeded=None, failed=None, total=None):
        """Metrics - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'succeeded': 'int',
            'failed': 'int',
            'total': 'int',
        }

        self.attribute_map = {
            'succeeded': 'succeeded',
            'failed': 'failed',
            'total': 'total',
        }

        self._succeeded = succeeded
        self._failed = failed
        self._total = total

    @property
    def succeeded(self):
        """Gets the succeeded of this Metrics.

        Number of commits built successfully.

        :return: The number of commits built successfully.
        :rtype: int
        """
        return self._succeeded

    @succeeded.setter
    def succeeded(self, succeeded):
        """Sets the succeeded of this Metrics.

        Number of commits built successfully.

        :param succeeded: The number of commits built successfully.
        :type: int
        """

        self._succeeded = succeeded

    @property
    def failed(self):
        """Gets the failed of this Metrics.

        Number of commits that failed to build.

        :return: The number of commits that failed to build.
        :rtype: int
        """
        return self._failed

    @failed.setter
    def failed(self, failed):
        """Sets the failed of this Metrics.

        Number of commits that failed to build.

        :param failed: The number of commits that failed to build.
        :type: int
        """

        self._failed = failed

    @property
    def total(self):
        """Gets the total of this Metrics.

        Number of commits processed in the period.

        :return: The total number of commits processed in the period.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this Metrics.

        Number of commits processed in the period.

        :param total: The total number of commits processed in the period.
        :type: int
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, Metrics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

from dlrnapi_client.models.metrics import Metrics
from dlrnapi_client.models.metrics import MetricsRequest


class TestMetricsRequest(unittest.TestCase):
    """MetricsRequest unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMetricsRequest(self):
        """Test MetricsRequest """
        model = MetricsRequest()
        expected = {'start_date': None, 'end_date': None,
                    'package_name': None}
        self.assertEqual(model.to_dict(), expected)


class TestMetrics(unittest.TestCase):
    """Metrics unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMetrics(self):
        """Test Metrics """
        model = Metrics()
        expected = {'succeeded': None, 'failed': None,
                    'total': None}
        self.assertEqual(model.to_dict(), expected)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import


# python 2 and python 3 compatibility library
from six import iteritems

from dlrnapi_client.api_client import ApiClient
from dlrnapi_client.configuration import Configuration


class DefaultApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def api_last_tested_repo_get(self, params, **kwargs):
        """Get the last tested repo since a specific time.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_last_tested_repo_get(params,
                                                  callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params params: The JSON params to post (required)
        :return: Repo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_last_tested_repo_get_with_http_info(params,
                                                                **kwargs)
        else:
            (data) = self.api_last_tested_repo_get_with_http_info(params,
                                                                  **kwargs)
            return data

    def api_last_tested_repo_get_with_http_info(self, params, **kwargs):
        """Get the last tested repo since a specific time.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_last_tested_repo_get_with_http_info(params,
                                                                 callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params params: The JSON params to post (required)
        :return: Repo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_last_tested_repo_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_last_tested_repo_get`")

        collection_formats = {}

        resource_path = '/api/last_tested_repo'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            # FIXME(jpena): we should deprecate in-body params in the future
            body_params = params['params']
            # Use in-URL params, too
            query_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Repo',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_last_tested_repo_post(self, params, **kwargs):
        """Get the last tested repo since a specific time

        (optionally for a CI job), and add an \"in progress\" entry in the CI
        job table for this.

        If a job_id is specified, the order of precedence for the repo returned
        is:

        - The last tested repo within that timeframe for that CI job.
        - The last tested repo within that timeframe for any CI job, so we can
          have several CIs converge on a single repo.
        - The last \"consistent\" repo, if no repo has been tested in the
          timeframe.

        If ``sequential_mode`` is set to true, a different algorithm is used.
        Another parameter ``previous_job_id`` needs to be specified, and the
        order of precedence for the repo returned is:
        - The last tested repo within that timeframe for the CI job described
          by ``previous_job_id``.
        - If no repo for ``previous_job_id`` is found, an error will be
          returned
        The sequential mode is meant to be used by CI pipelines, where a CI (n)
        job needs to use the same repo tested by CI (n-1).

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_last_tested_repo_post(params,
                                                   callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params1 params: The JSON params to post (required)
        :return: Repo
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_last_tested_repo_post_with_http_info(params,
                                                                 **kwargs)
        else:
            (data) = self.api_last_tested_repo_post_with_http_info(params,
                                                                   **kwargs)
            return data

    def api_last_tested_repo_post_with_http_info(self, params, **kwargs):
        """Get the last tested repo since a specific time

        (optionally for a CI job), and add an \"in progress\" entry in the CI
        job table for this.

        If a job_id is specified, the order of precedence for the repo returned
        is:

        - The last tested repo within that timeframe for that CI job.
        - The last tested repo within that timeframe for any CI job, so we can
          have several CIs converge on a single repo.
        - The last \"consistent\" repo, if no repo has been tested in the
          timeframe.

        If ``sequential_mode`` is set to true, a different algorithm is used.
        Another parameter ``previous_job_id`` needs to be specified, and the
        order of precedence for the repo returned is:
        - The last tested repo within that timeframe for the CI job described
          by ``previous_job_id``.
        - If no repo for ``previous_job_id`` is found, an error will be
          returned
        The sequential mode is meant to be used by CI pipelines, where a CI (n)
        job needs to use the same repo tested by CI (n-1).
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_last_tested_repo_post_with_http_info(params,
                                                    callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params1 params: The JSON params to post (required)
        :return: Repo
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_last_tested_repo_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_last_tested_repo_post`")

        collection_formats = {}

        resource_path = '/api/last_tested_repo'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            body_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basicAuth']

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Repo',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_promote_post(self, params, **kwargs):
        """Promote a repository.

        This can be implemented as a local symlink creation in the DLRN worker,
        or any other form in the future.  Note the API will refuse to promote
        using promote_name=\"consistent\" or \"current\", since those are
        reserved keywords for DLRN.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promote_post(params, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Promotion params: The JSON params to post (required)
        :return: Promotion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_promote_post_with_http_info(params, **kwargs)
        else:
            (data) = self.api_promote_post_with_http_info(params, **kwargs)
            return data

    def api_promote_post_with_http_info(self, params, **kwargs):
        """Promote a repository.

        This can be implemented as a local symlink creation in the DLRN worker,
        or any other form in the future.  Note the API will refuse to promote
        using promote_name=\"consistent\" or \"current\", since those are
        reserved keywords for DLRN.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promote_post_with_http_info(params,
                                                     callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Promotion params: The JSON params to post (required)
        :return: Promotion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_promote_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_promote_post`")

        collection_formats = {}

        resource_path = '/api/promote'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            body_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basicAuth']

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Promotion',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_promote_batch_post(self, params, **kwargs):
        """Atomically promote a list of repositories.

        This is the equivalent of calling api_promote_post multiple times, one
        with each commit/distro_hash combination. The only difference is that
        the call is atomic, and when components are enabled, the aggregated
        repo files are only updated once.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promote_batch_post(params,
                                                callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param  list[Promotion] params: The JSON params to post (required)
        :return: Promotion
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_promote_batch_post_with_http_info(params, **kwargs)
        else:
            (data) = self.api_promote_batch_post_with_http_info(params,
                                                                **kwargs)
            return data

    def api_promote_batch_post_with_http_info(self, params, **kwargs):
        """Atomically promote a list of repositories.

        This is the equivalent of calling api_promote_post multiple times, one
        with each commit/distro_hash combination. The only difference is that
        the call is atomic, and when components are enabled, the aggregated
        repo files are only updated once.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promote_batch_post_with_http_info(params,
                                                               callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param  list[Promotion] params: The JSON params to post (required)
        :return: Promotion
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_promote_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_promote_post`")

        collection_formats = {}

        resource_path = '/api/promote-batch'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            body_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basicAuth']

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Promotion',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_remote_import_post(self, params, **kwargs):
        """Import a commit built by another instance.

        This API call mimics the behavior of the ``dlrn-remote`` command,
        with the only exception of not being able to specify a custom
        rdoinfo location.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_remote_import_post(params,
                                                callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelImport params: The JSON params to post (required)
        :return: ModelImport
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_remote_import_post_with_http_info(params, **kwargs)
        else:
            (data) = self.api_remote_import_post_with_http_info(params,
                                                                **kwargs)
            return data

    def api_remote_import_post_with_http_info(self, params, **kwargs):
        """Import a commit built by another instance.

        This API call mimics the behavior of the ``dlrn-remote`` command,
        with the only exception of not being able to specify a custom
        rdoinfo location.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_remote_import_post_with_http_info(params,
                                                   callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param ModelImport params: The JSON params to post (required)
        :return: ModelImport
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_remote_import_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_remote_import_post`")

        collection_formats = {}

        resource_path = '/api/remote/import'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            body_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basicAuth']

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='ModelImport',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_repo_status_get(self, params, **kwargs):
        """Get all the CI reports for a specific repository.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_repo_status_get(params,
                                             callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params2 params: The JSON params to post (required)
        :return: list[CIVote]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_repo_status_get_with_http_info(params, **kwargs)
        else:
            (data) = self.api_repo_status_get_with_http_info(params, **kwargs)
            return data

    def api_repo_status_get_with_http_info(self, params, **kwargs):
        """Get all the CI reports for a specific repository.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_repo_status_get_with_http_info(params,
                                                callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params2 params: The JSON params to post (required)
        :return: list[CIVote]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_repo_status_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_repo_status_get`")

        collection_formats = {}

        resource_path = '/api/repo_status'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            # FIXME(jpena): we should deprecate in-body params in the future
            body_params = params['params']
            # Use in-URL params, too
            query_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[CIVote]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_agg_status_get(self, params, **kwargs):
        """Get all the CI reports for a specific aggregated repo.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_agg_status_get(params,
                                             callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param AggQuery params: The JSON params to post (required)
        :return: list[CIAggVote]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_agg_status_get_with_http_info(params, **kwargs)
        else:
            (data) = self.api_agg_status_get_with_http_info(params, **kwargs)
            return data

    def api_agg_status_get_with_http_info(self, params, **kwargs):
        """Get all the CI reports for a specific aggregated repo.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_agg_status_get_with_http_info(params,
                                                callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param AggQuery params: The JSON params to post (required)
        :return: list[CIAggVote]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_agg_status_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_agg_status_get`")

        collection_formats = {}

        resource_path = '/api/agg_status'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            # FIXME(jpena): we should deprecate in-body params in the future
            body_params = params['params']
            # Use in-URL params, too
            query_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[CIAggVote]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_report_result_post(self, params, **kwargs):
        """Report the result of a CI job.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_report_result_post(params,
                                                callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params3 params: The JSON params to post (required)
        :return: CIVote
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_report_result_post_with_http_info(params, **kwargs)
        else:
            (data) = self.api_report_result_post_with_http_info(params,
                                                                **kwargs)
            return data

    def api_report_result_post_with_http_info(self, params, **kwargs):
        """Report the result of a CI job.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_report_result_post_with_http_info(params,
                                                    callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Params3 params: The JSON params to post (required)
        :return: CIVote
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_report_result_post" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_report_result_post`")

        collection_formats = {}

        resource_path = '/api/report_result'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            body_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['basicAuth']

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='CIVote',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_promotions_get(self, params, **kwargs):
        """Get promotions, optionally for a specific repository or promotion
        name.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promotions_get(params,
                                             callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Promotion params: The JSON params to post (required)
        :return: list[Promotion]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_promotions_get_with_http_info(params, **kwargs)
        else:
            (data) = self.api_promotions_get_with_http_info(params, **kwargs)
            return data

    def api_promotions_get_with_http_info(self, params, **kwargs):
        """Get all the CI reports for a specific repository.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promotions_get_with_http_info(params,
                                                callback=callback_function)


        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Promotion params: The JSON params to post (required)
        :return: list[Promotion]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_promotions_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_promotions_get`")

        collection_formats = {}

        resource_path = '/api/promotions'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            # FIXME(jpena): we should deprecate in-body params in the future
            body_params = params['params']
            # Use in-URL params, too
            query_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='list[Promotion]',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)

    def api_build_metrics_get(self, params, **kwargs):
        """Get build metrics, optionally for a specific package name.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_build_metrics_get(params,
                                               callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param MetricRequest params: The JSON params to post (required)
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.api_build_metrics_get_with_http_info(params, **kwargs)
        else:
            (data) = self.api_build_metrics_get_with_http_info(params,
                                                               **kwargs)
            return data

    def api_build_metrics_get_with_http_info(self, params, **kwargs):
        """Get build metrics, optionally for a specific package name.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.api_promotions_get_with_http_info(params,
                                                callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param MetricRequest params: The JSON params to post (required)
        :return: Metrics
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['params']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_build_metrics_get" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'params' is set
        if ('params' not in params) or (params['params'] is None):
            raise ValueError("Missing the required parameter `params` when "
                             "calling `api_build_metrics_get`")

        collection_formats = {}

        resource_path = '/api/metrics/builds'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'params' in params:
            # FIXME(jpena): we should deprecate in-body params in the future
            body_params = params['params']
            # Use in-URL params, too
            query_params = params['params']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='Metrics',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get(
                                            '_return_http_data_only'),
                                        _preload_content=params.get(
                                            '_preload_content', True),
                                        _request_timeout=params.get(
                                            '_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems


class Params2(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, commit_hash=None, distro_hash=None, extended_hash=None,
                 success=None):
        """Params2 - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'commit_hash': 'str',
            'distro_hash': 'str',
            'extended_hash': 'str',
            'success': 'bool'
        }

        self.attribute_map = {
            'commit_hash': 'commit_hash',
            'distro_hash': 'distro_hash',
            'extended_hash': 'extended_hash',
            'success': 'success'
        }

        self._commit_hash = commit_hash
        self._distro_hash = distro_hash
        self._extended_hash = extended_hash
        self._success = success

    @property
    def commit_hash(self):
        """Gets the commit_hash of this Params2.

        commit_hash of the repo to fetch information for.

        :return: The commit_hash of this Params2.
        :rtype: str
        """
        return self._commit_hash

    @commit_hash.setter
    def commit_hash(self, commit_hash):
        """Sets the commit_hash of this Params2.

        commit_hash of the repo to fetch information for.

        :param commit_hash: The commit_hash of this Params2.
        :type: str
        """
        if commit_hash is None:
            raise ValueError("Invalid value for `commit_hash`, must not be"
                             " `None`")

        self._commit_hash = commit_hash

    @property
    def distro_hash(self):
        """Gets the distro_hash of this Params2.

        distro_hash of the repo to fetch information for.

        :return: The distro_hash of this Params2.
        :rtype: str
        """
        return self._distro_hash

    @distro_hash.setter
    def distro_hash(self, distro_hash):
        """Sets the distro_hash of this Params2.

        distro_hash of the repo to fetch information for.

        :param distro_hash: The distro_hash of this Params2.
        :type: str
        """
        if distro_hash is None:
            raise ValueError("Invalid value for `distro_hash`, must not be"
                             " `None`")

        self._distro_hash = distro_hash

    @property
    def extended_hash(self):
        """Gets the extended_hash of this Params2.

        extended_hash of tested repo

        :return: The extended_hash of this Params2.
        :rtype: str
        """
        return self._extended_hash

    @extended_hash.setter
    def extended_hash(self, extended_hash):
        """Sets the extended_hash of this Params2.

        extended_hash of tested repo

        :param extended_hash: The extended_hash of this Params2.
        :type: str
        """

        self._extended_hash = extended_hash

    @property
    def success(self):
        """Gets the success of this Params2.

        If set to a value, only return the CI reports with the specified vote.
        If not set, return all CI reports.

        :return: The success of this Params2.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this Params2.

        If set to a value, only return the CI reports with the specified vote.
        If not set, return all CI reports.

        :param success: The success of this Params2.
        :type: bool
        """

        self._success = success

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, Params2):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import dlrnapi_client
from dlrnapi_client.apis.default_api import DefaultApi


class MockApiClient(object):
    def call_api(self, resource_path, method,
                 path_params=None, query_params=None, header_params=None,
                 body=None, post_params=None, files=None,
                 response_type=None, auth_settings=None, callback=None,
                 _return_http_data_only=None, collection_formats=None,
                 _preload_content=True,
                 _request_timeout=None):
        return resource_path, method

    def select_header_accept(self, accepts):
        return 'application/json'

    def select_header_content_type(self, content_types):
        return 'application/json'


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs """

    def setUp(self):
        self.api = DefaultApi()
        self.api_client = MockApiClient()

    def tearDown(self):
        pass

    def test_api_last_tested_repo_get(self):
        """Test case for api_last_tested_repo_get """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.Params()
        path, method = default_api.api_last_tested_repo_get(params)
        self.assertEqual(path, '/api/last_tested_repo')
        self.assertEqual(method, 'GET')

    def test_api_last_tested_repo_post(self):
        """Test case for api_last_tested_repo_post """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.Params1()
        path, method = default_api.api_last_tested_repo_post(params)
        self.assertEqual(path, '/api/last_tested_repo')
        self.assertEqual(method, 'POST')

    def test_api_promote_post(self):
        """Test case for api_promote_post """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.Promotion()
        path, method = default_api.api_promote_post(params)
        self.assertEqual(path, '/api/promote')
        self.assertEqual(method, 'POST')

    def test_api_promotions_get(self):
        """Test case for api_promotions_get """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.Promotion()
        path, method = default_api.api_promotions_get(params)
        self.assertEqual(path, '/api/promotions')
        self.assertEqual(method, 'GET')

    def test_api_build_metrics_get(self):
        """Test case for api_build_metrics_get """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.MetricsRequest()
        path, method = default_api.api_build_metrics_get(params)
        self.assertEqual(path, '/api/metrics/builds')
        self.assertEqual(method, 'GET')

    def test_api_remote_import_post(self):
        """Test case for api_remote_import_post """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.ModelImport()
        path, method = default_api.api_remote_import_post(params)
        self.assertEqual(path, '/api/remote/import')
        self.assertEqual(method, 'POST')

    def test_api_repo_status_get(self):
        """Test case for api_repo_status_get """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.Params2()
        path, method = default_api.api_repo_status_get(params)
        self.assertEqual(path, '/api/repo_status')
        self.assertEqual(method, 'GET')

    def test_api_report_result_post(self):
        """Test case for api_report_result_post """
        default_api = DefaultApi(api_client=self.api_client)
        params = dlrnapi_client.Params3()
        path, method = default_api.api_report_result_post(params)
        self.assertEqual(path, '/api/report_result')
        self.assertEqual(method, 'POST')


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/python
#   Copyright Red Hat, Inc. All Rights Reserved.
#
#   Licensed under the Apache License, Version 2.0 (the "License"); you may
#   not use this file except in compliance with the License. You may obtain
#   a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#   License for the specific language governing permissions and limitations
#   under the License.
#

from ansible.module_utils.basic import AnsibleModule
import dlrnapi_client
from dlrnapi_client.rest import ApiException
from dlrnapi_client.shell import command_funcs

DOCUMENTATION = '''
---
module: dlrn_api
short_description: Ansible module to manage the DLRN API
version_added: "1.0"
author: "jpena <jpena@redhat.com>"
description:
    - Ansible module to manage the DLRN API
options:
    action:
        description:
            - Action to take
        choices: [repo-get, repo-use, repo-status, report-result, repo-promote,
                  repo-promote-batch, commit-import, promotion-get,
                  build-metrics, agg-status]
        required: true
    host:
        description:
            - URL for the DLRN API host
        required: true
    user:
        description:
            - Username for operations requiring authentication. Mandatory if
              action is repo-use, report-result, repo-promote or commit-import
    password:
        description:
            - Password for operations requiring authentication. Mandatory if
              action is repo-use, report-result, repo-promote or commit-import
    reporting_job_id:
        description:
            - If action is repo-use, name of the CI that will add the
              "in progress" entry in the CI job table.
    max_age:
        description:
            - If action is repo-get or repo-use, maximum age in hours for the
              repo to be considered.
        default: 0
    success:
        description:
            - If action is repo-get or repo-use, find repos with a
              successful/unsuccessful vote (as specified). If not set,
              any tested repo will be considered.
            - If action is report-result, was the CI execution successful?
    job_id:
        description:
            - If action is repo-get or repo-use, name of the CI that sent the
              vote. If not set, no filter will be set on CI.
            - If action is report-result, name of the CI sending the vote
    sequential_mode:
        description:
            - If action is repo-get or repo-use, use the sequential mode
              algorithm. In this case, return the last tested repo within that
              timeframe for the CI job described by previous_job_id.
        default: False
    previous_job_id:
        description:
            - If sequential_mode is set to true, look for jobs tested by
              the CI identified by previous_job_id.
    commit_hash:
        description:
            - If action is repo-status, commit_hash of the repo to fetch
              information for.
            - If action is report-result, commit_hash of tested repo.
            - If action is repo-promote, commit_hash of the repo to be
              promoted.
            - If action is promotion-get, filter results for this commit hash.
    distro_hash:
        description:
            - If action is repo-status, distro_hash of the repo to fetch
              information for.
            - If action is report-result, distro_hash of tested repo.
            - If action is repo-promote, distro_hash of the repo to be
              promoted.
            - If action is promotion-get, filter results for this distro hash.
    extended_hash:
        description:
            - If action is repo-status, extended_hash of the repo to fetch
              information for.
            - If action is report-result, extended_hash of tested repo.
            - If action is repo-promote, extended_hash of the repo to be
              promoted.
            - If action is promotion-get, filter results for this extended
              hash.
    agg_hash:
        description:
            - If action is report-result, hash of the aggregated repo to
              report a result on.
            - If action is promotion-get or agg-status, filter on the votes or
              promotions related to this aggregated repo hash.
    info_url:
        description:
            - If action is report-result, URL where to find additional
              information from the CI execution.
    timestamp:
        description:
            - If action is report-result, timestamp (in seconds since the
              epoch) for the CI execution
    notes:
        description:
            - If action is report-result, additional notes.
    promote_name:
        description:
            - If action is repo-promote, name to be used for the promotion.
            - If action is promotion-get, filter results by this promotion
              name.
    repo_url:
        description:
            - If action is commit-import, base repository URL for imported
              remote repo
    start_date:
        description:
            - If action is build-metrics, start date to consider for the
              metrics, in YYYY-mm-dd format.
    end_date:
        description:
            - If action is build-metrics, end date to consider for the
              metrics, in YYYY-mm-dd format.
    package_name:
        description:
            - If action is build-metrics, filter results for this package.
    component:
        description:
            - If action is repo-get, repo-use or promotion-get, filter on
              this component.
    hash_pairs:
        description:
            - If action is repo-promote-batch, this is a list of commit_hash
              and distro_hash pairs to be promoted using promote_name.
requirements:
    - "python >= 2.7"
    - "python-dlrnapi_client"
'''

EXAMPLES = '''
# Get the last repo tested by any CI
- dlrn_api:
    action: repo-get
    host: http://dlrn.example.com:5000
  register: result

# Get the last repo tested by any CI in the last 4 hours
- dlrn_api:
    action: repo-get
    host: http://dlrn.example.com:5000
    max_age: 4
  register: result

# Get the last repo, successfully tested by the foo-ci CI, in the last 24 hours
- dlrn_api:
    action: repo-get
    host: http://dlrn.example.com:5000
    max_age: 24
    job_id: foo-ci
    success: true
  register: result

# Get and start using the last repo, that failed testing by the foo-ci CI, in
# the last 6 hours, and mark it as being used by the bar-ci CI
- dlrn_api:
    action: repo-use
    host: http://dlrn.example.com:5000
    user: myuser
    password: mypasswd
    max_age: 6
    reporting_job_id: bar-ci
    job_id: foo-ci
    success: false
  register: result

# Get the CI reports for a specific commit
- dlrn_api:
    action: repo-status
    host: http://dlrn.example.com:5000
    commit_hash: 3a9326f251b9a4162eb0dfa9f1c924ef47c2c55a
    distro_hash: 024e24f0cf4366c2290c22f24e42de714d1addd1
  register: result

# Get the promotions for a specific job
- dlrn_api:
    action: promotion-get
    host: http://dlrn.example.com:5000
    promote_name: foo-ci
  register: result

# Report result on a CI job ran by foo-ci
- dlrn_api:
    action: report-result
    host: http://dlrn.example.com:5000
    user: myuser
    password: mypasswd
    job_id: foo-ci
    commit_hash: 3a9326f251b9a4162eb0dfa9f1c924ef47c2c55a
    distro_hash: 024e24f0cf4366c2290c22f24e42de714d1addd1
    info_url: http://ci.example.com/job_id?1
    timestamp: 1431949433
    success: true
    notes: blablabla

# Promote a repository
- dlrn_api:
    action: repo-promote
    host: http://dlrn.example.com:5000
    user: myuser
    password: mypasswd
    commit_hash: 3a9326f251b9a4162eb0dfa9f1c924ef47c2c55a
    distro_hash: 024e24f0cf4366c2290c22f24e42de714d1addd1
    promote_name: current-passed-ci

# Do a batch promotion
- dlrn_api:
    action: repo-promote-batch
    host: http://dlrn.example.com:5000
    user: myuser
    password: mypasswd
    hash_pairs:
        - commit_hash: 3a9326f251b9a4162eb0dfa9f1c924ef47c2c55a
          distro_hash: 024e24f0cf4366c2290c22f24e42de714d1addd1
        - commit_hash: 3a9326f251b9a4162eb0dfa9f1c924ef47c2c533
          distro_hash: 024e24f0cf4366c2290c22f24e42de714d1addae
    promote_name: current-passed-ci

# Import a remote commit
- dlrn_api:
    action: commit-import
    host: http://dlrn.example.com:5000
    user: myuser
    password: mypasswd
    repo_url: http://builder.example.com/3a9326f251b9a4162eb0_024e24f0
'''
auth_required_actions = ['repo-use', 'report-result', 'repo-promote',
                         'repo-promote-batch', 'commit-import']


class DLRNAPIWrapper(object):
    """Wrapper class

    It is meant to provide the options dict, and a parameter verification
    method
    """
    def __init__(self, params):
        self.reporting_job_id = params.get('reporting_job_id')
        self.max_age = params.get('max_age')
        self.success = params.get('success')
        self.job_id = params.get('job_id')
        self.sequential = params.get('sequential_mode')
        self.previous_job_id = params.get('previous_job_id')
        self.commit_hash = params.get('commit_hash')
        self.distro_hash = params.get('distro_hash')
        self.extended_hash = params.get('extended_hash')
        self.info_url = params.get('info_url')
        self.timestamp = params.get('timestamp')
        self.notes = params.get('notes')
        self.promote_name = params.get('promote_name')
        self.repo_url = params.get('repo_url')
        self.component = params.get('component')
        self.agg_hash = params.get('agg_hash')
        self.hash_pairs = params.get('hash_pairs')

    def check_options(self, action, module):
        if action == 'repo-use':
            if self.reporting_job_id is None:
                module.fail_json(msg="Missing parameter reporting_job_id")
        elif action == 'report-result':
            if self.agg_hash is not None and\
               (self.commit_hash is not None or self.distro_hash is not None):
                module.fail_json(msg="agg_hash is incompatible with"
                                     "commit_hash and distro_hash")
            if self.agg_hash is None and self.commit_hash is None and\
               self.distro_hash is None:
                module.fail_json(msg="Must specify either agg_hash or"
                                     "commit_hash and distro_hash")
            if (self.commit_hash is not None and self.distro_hash is None):
                module.fail_json(msg="Missing parameter distro_hash")
            if (self.distro_hash is not None and self.commit_hash is None):
                module.fail_json(msg="Missing parameter commit_hash")
            if self.job_id is None:
                module.fail_json(msg="Missing parameter job_id")
            if self.info_url is None:
                module.fail_json(msg="Missing parameter info_url")
            if self.timestamp is None:
                module.fail_json(msg="Missing parameter timestamp")
            if self.success is None:
                module.fail_json(msg="Missing parameter success")
        elif action == 'repo-promote':
            if self.commit_hash is None:
                module.fail_json(msg="Missing parameter commit_hash")
            if self.distro_hash is None:
                module.fail_json(msg="Missing parameter distro_hash")
            if self.promote_name is None:
                module.fail_json(msg="Missing parameter promote_name")
        elif action == 'repo-promote-batch':
            if self.hash_pairs is None:
                module.fail_json(msg="Missing parameter hash_pairs")
            if self.promote_name is None:
                module.fail_json(msg="Missing parameter promote_name")
            # The hash_pairs format is different when passed to the client,
            # so convert it here
            hash_pairs = ''
            for pair in self.hash_pairs[:-1]:
                if 'extended_hash' in pair:
                    hash_pairs += '%s_%s_%s,' % (pair['commit_hash'],
                                                 pair['distro_hash'],
                                                 pair['extended_hash'])
                else:
                    hash_pairs += '%s_%s,' % (pair['commit_hash'],
                                              pair['distro_hash'])
            if 'extended_hash' in self.hash_pairs[-1]:
                hash_pairs += '%s_%s_%s' % (
                    self.hash_pairs[-1]['commit_hash'],
                    self.hash_pairs[-1]['distro_hash'],
                    self.hash_pairs[-1]['extended_hash'])
            else:
                hash_pairs += '%s_%s' % (self.hash_pairs[-1]['commit_hash'],
                                         self.hash_pairs[-1]['distro_hash'])
            self.hash_pairs = hash_pairs
        elif action == 'commit-import':
            if self.repo_url is None:
                module.fail_json(msg="Missing parameter repo_url")
        elif action == 'promotion-get':
            if (self.commit_hash is not None and self.distro_hash is None):
                module.fail_json(msg="Missing parameter distro_hash")
            if (self.distro_hash is not None and self.commit_hash is None):
                module.fail_json(msg="Missing parameter commit_hash")
        elif action == 'build-metrics':
            if self.start_date is None:
                module.fail_json(msg="Missing start_date")
            if self.end_date is None:
                module.fail_json(msg="Missing end_date")


def main():
    module = AnsibleModule(
        argument_spec=dict(
            action=dict(required=True,
                        choices=['repo-get', 'repo-use',
                                 'repo-status', 'report-result',
                                 'repo-promote', 'repo-promote-batch',
                                 'commit-import', 'promotion-get',
                                 'build-metrics', 'agg-status']),
            host=dict(required=True),
            user=dict(),
            password=dict(no_log=True),
            reporting_job_id=dict(),
            max_age=dict(default='0', type='int'),
            success=dict(type='bool'),
            job_id=dict(),
            sequential_mode=dict(type='bool', default=False),
            previous_job_id=dict(),
            commit_hash=dict(),
            distro_hash=dict(),
            extended_hash=dict(),
            info_url=dict(),
            timestamp=dict(),
            notes=dict(),
            promote_name=dict(),
            repo_url=dict(),
            start_date=dict(),
            end_date=dict(),
            package_name=dict(),
            component=dict(),
            agg_hash=dict(),
            hash_pairs=dict(type='list')
        )
    )

    action = module.params['action']
    username = module.params['user']
    password = module.params['password']
    if action in auth_required_actions and (username is None or
                                            password is None):
        module.fail_json(msg="Action %s requires authentication" % action)

    api_client = dlrnapi_client.ApiClient(host=module.params['host'])
    dlrnapi_client.configuration.username = username
    dlrnapi_client.configuration.password = password
    api_instance = dlrnapi_client.DefaultApi(api_client=api_client)

    options = DLRNAPIWrapper(module.params)
    options.check_options(action, module)

    try:
        output = command_funcs[action](api_instance, options)
        if type(output) == list:
            output_f = [x.to_dict() for x in output]
        else:
            output_f = output.to_dict()
        module.exit_json(changed=True, result=output_f)
    except ApiException as e:
        module.fail_json(msg="Exception when calling "
                             "%s: %s\n" % (command_funcs[action], e))


if __name__ == '__main__':
    main()



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

from dlrnapi_client.models.params import Params


class TestParams(unittest.TestCase):
    """Params unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testParams(self):
        """Test Params """
        model = Params()
        expected = {'max_age': None, 'sequential_mode': None, 'job_id': None,
                    'success': None, 'previous_job_id': None,
                    'component': None}
        self.assertEqual(model.to_dict(), expected)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems


class Promotion(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, commit_hash=None, distro_hash=None, extended_hash=None,
                 aggregate_hash=None, promote_name=None, timestamp=None,
                 user=None, repo_hash=None, repo_url=None, component=None):
        """Promotion - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'commit_hash': 'str',
            'distro_hash': 'str',
            'extended_hash': 'str',
            'aggregate_hash': 'str',
            'promote_name': 'str',
            'timestamp': 'int',
            'user': 'str',
            'repo_hash': 'str',
            'repo_url': 'str',
            'component': 'str',
        }

        self.attribute_map = {
            'commit_hash': 'commit_hash',
            'distro_hash': 'distro_hash',
            'extended_hash': 'extended_hash',
            'aggregate_hash': 'aggregate_hash',
            'promote_name': 'promote_name',
            'timestamp': 'timestamp',
            'user': 'user',
            'repo_hash': 'repo_hash',
            'repo_url': 'repo_url',
            'component': 'component',
        }

        self._commit_hash = commit_hash
        self._distro_hash = distro_hash
        self._extended_hash = extended_hash
        self._aggregate_hash = aggregate_hash
        self._promote_name = promote_name
        self._timestamp = timestamp
        self._user = user
        self._repo_hash = repo_hash
        self._repo_url = repo_url
        self._component = component

    @property
    def commit_hash(self):
        """Gets the commit_hash of this Promotion.

        commit_hash of promoted repo

        :return: The commit_hash of this Promotion.
        :rtype: str
        """
        return self._commit_hash

    @commit_hash.setter
    def commit_hash(self, commit_hash):
        """Sets the commit_hash of this Promotion.

        commit_hash of promoted repo

        :param commit_hash: The commit_hash of this Promotion.
        :type: str
        """

        self._commit_hash = commit_hash

    @property
    def distro_hash(self):
        """Gets the distro_hash of this Promotion.

        distro_hash of promoted repo

        :return: The distro_hash of this Promotion.
        :rtype: str
        """
        return self._distro_hash

    @distro_hash.setter
    def distro_hash(self, distro_hash):
        """Sets the distro_hash of this Promotion.

        distro_hash of promoted repo

        :param distro_hash: The distro_hash of this Promotion.
        :type: str
        """

        self._distro_hash = distro_hash

    @property
    def extended_hash(self):
        """Gets the extended_hash of this Promotion Query.

        distro_hash of promoted repo

        :return: The extended_hash of this Promotion Query.
        :rtype: str
        """
        return self._extended_hash

    @extended_hash.setter
    def extended_hash(self, extended_hash):
        """Sets the extended_hash of this Promotion Query.

        extended_hash of promoted repo

        :param extended_hash: The extended_hash of this Promotion Query.
        :type: str
        """

        self._extended_hash = extended_hash

    @property
    def aggregate_hash(self):
        """Gets the aggregate_hash of this Promotion.

        aggregate_hash of promoted repo

        :return: The aggregate_hash of this Promotion.
        :rtype: str
        """
        return self._aggregate_hash

    @aggregate_hash.setter
    def aggregate_hash(self, aggregate_hash):
        """Sets the aggregate_hash of this Promotion.

        aggregate_hash of promoted repo

        :param aggregate_hash: The aggregate_hash of this Promotion.
        :type: str
        """

        self._aggregate_hash = aggregate_hash

    @property
    def promote_name(self):
        """Gets the promote_name of this Promotion.

        name used for the promotion

        :return: The promote_name of this Promotion.
        :rtype: str
        """
        return self._promote_name

    @promote_name.setter
    def promote_name(self, promote_name):
        """Sets the promote_name of this Promotion.

        name used for the promotion

        :param promote_name: The promote_name of this Promotion.
        :type: str
        """

        self._promote_name = promote_name

    @property
    def timestamp(self):
        """Gets the timestamp of this Repo.

        Timestamp for this CI Vote (taken from the DLRN system time)

        :return: The timestamp of this Repo.
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Repo.

        Timestamp for this CI Vote (taken from the DLRN system time)

        :param timestamp: The timestamp of this Repo.
        :type: int
        """

        self._timestamp = timestamp

    @property
    def timestamp(self):
        """Gets the timestamp of this Repo.

        Timestamp for this CI Vote (taken from the DLRN system time)

        :return: The timestamp of this Repo.
        :rtype: int
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this Repo.

        Timestamp for this CI Vote (taken from the DLRN system time)

        :param timestamp: The timestamp of this Repo.
        :type: int
        """

        self._timestamp = timestamp

    @property
    def user(self):
        """Gets the user of this Promotion Query.

        User who created this promotion

        :return: The user.
        :rtype: int
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this Promotion Query.

        User who created this promotion

        :param user: The user.
        :type: int
        """

        self._user = user

    @property
    def repo_hash(self):
        """Gets the repo_hash of this Promotion.

        repo_hash of promoted repo

        :return: The repo_hash of this Promotion.
        :rtype: str
        """
        return self._repo_hash

    @repo_hash.setter
    def repo_hash(self, repo_hash):
        """Sets the repo_hash of this Promotion.

        repo_hash of promoted repo

        :param repo_hash: The repo_hash of this Promotion.
        :type: str
        """

        self._repo_hash = repo_hash

    @property
    def repo_url(self):
        """Gets the repo_url of this Promotion.

        repo_url of promoted repo

        :return: The repo_url of this Promotion.
        :rtype: str
        """
        return self._repo_url

    @repo_url.setter
    def repo_url(self, repo_url):
        """Sets the repo_url of this Promotion.

        repo_url of promoted repo

        :param repo_url: The repo_url of this Promotion.
        :type: str
        """

        self._repo_url = repo_url

    @property
    def component(self):
        """Gets the component of this Promotion.

        component of promoted repo

        :return: The component of this Promotion.
        :rtype: str
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this Promotion.

        component of promoted repo

        :param component: The component of this Promotion.
        :type: str
        """

        self._component = component

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, Promotion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems


class ModelImport(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, repo_url=None):
        """ModelImport - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'repo_url': 'str'
        }

        self.attribute_map = {
            'repo_url': 'repo_url'
        }

        self._repo_url = repo_url

    @property
    def repo_url(self):
        """Gets the repo_url of this ModelImport.

        Base repository URL for imported remote repo

        :return: The repo_url of this ModelImport.
        :rtype: str
        """
        return self._repo_url

    @repo_url.setter
    def repo_url(self, repo_url):
        """Sets the repo_url of this ModelImport.

        Base repository URL for imported remote repo

        :param repo_url: The repo_url of this ModelImport.
        :type: str
        """

        self._repo_url = repo_url

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, ModelImport):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import setuptools

setuptools.setup(
    setup_requires=['pbr'],
    pbr=True)



# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from __future__ import print_function
import argparse
import json
import os
import sys

import dlrnapi_client
from dlrnapi_client.rest import ApiException


# Helper class to allow us to convert API response objects into JSON for output
class ResponseEncoder(json.JSONEncoder):
    def default(self, obj):
        # All the API response objects have a "swagger_types" attribute
        if hasattr(obj, 'swagger_types'):
            return obj.to_dict()
        # Use the default encoder for anything else
        return json.JSONEncoder.default(self, obj)


def get_last_tested_repo(api_instance, options):
    params = dlrnapi_client.Params()  # Params | The JSON params to post
    params.max_age = options.max_age
    if options.success:
        params.success = str(options.success)
    if options.component:
        params.component = str(options.component)
    params.job_id = options.job_id
    params.sequential_mode = str(options.sequential)
    params.previous_job_id = options.previous_job_id

    try:
        api_response = api_instance.api_last_tested_repo_get(params)
        return api_response
    except ApiException as e:
        raise e


def post_last_tested_repo(api_instance, options):
    params = dlrnapi_client.Params1()  # Params1 | The JSON params to post
    params.max_age = options.max_age
    params.reporting_job_id = options.reporting_job_id
    if options.success:
        params.success = str(options.success)
    if options.component:
        params.component = str(options.component)
    params.job_id = options.job_id
    params.sequential_mode = str(options.sequential)
    params.previous_job_id = options.previous_job_id

    try:
        api_response = api_instance.api_last_tested_repo_post(params)
        return api_response
    except ApiException as e:
        raise e


def repo_status(api_instance, options):
    params = dlrnapi_client.Params2()  # Params2 | The JSON params to post
    params.commit_hash = options.commit_hash
    params.distro_hash = options.distro_hash
    if options.success:
        params.success = str(options.success)
    if options.extended_hash:
        params.extended_hash = options.extended_hash

    try:
        api_response = api_instance.api_repo_status_get(params)
        return api_response
    except ApiException as e:
        raise e


def agg_status(api_instance, options):
    params = dlrnapi_client.AggQuery()  # AggQuery | The JSON params to post
    params.aggregate_hash = options.agg_hash
    if options.success:
        params.success = str(options.success)

    try:
        api_response = api_instance.api_agg_status_get(params)
        return api_response
    except ApiException as e:
        raise e


def repo_promote(api_instance, options):
    params = dlrnapi_client.Promotion()  # Promotion | The JSON params to post
    params.commit_hash = options.commit_hash
    params.distro_hash = options.distro_hash
    params.extended_hash = options.extended_hash
    params.promote_name = options.promote_name
    try:
        api_response = api_instance.api_promote_post(params)
        return api_response
    except ApiException as e:
        raise e


def repo_promote_batch(api_instance, options):
    params = list()
    hash_pairs = options.hash_pairs.split(',')
    for pair in hash_pairs:
        pair_list = pair.split('_')
        commit_hash = pair_list[0]
        distro_hash = pair_list[1]
        if len(pair_list) > 2:
            extended_hash = '_'.join(pair_list[2:])
        else:
            extended_hash = None
        param = dlrnapi_client.Promotion()
        param.commit_hash = commit_hash
        param.distro_hash = distro_hash
        param.extended_hash = extended_hash
        param.promote_name = options.promote_name
        params.append(param)
    try:
        api_response = api_instance.api_promote_batch_post(params)
        return api_response
    except ApiException as e:
        raise e


def get_promotions(api_instance, options):
    params = dlrnapi_client.PromotionQuery()  # PromotionQuery
    if options.commit_hash:
        params.commit_hash = options.commit_hash
    if options.distro_hash:
        params.distro_hash = options.distro_hash
    if options.extended_hash:
        params.extended_hash = options.extended_hash
    if options.agg_hash:
        params.aggregate_hash = options.agg_hash
    if options.promote_name:
        params.promote_name = options.promote_name
    if options.offset:
        params.offset = options.offset
    if options.limit:
        params.limit = options.limit
    if options.component:
        params.component = options.component

    try:
        api_response = api_instance.api_promotions_get(params)
        return api_response
    except ApiException as e:
        raise e


def report_result(api_instance, options):
    params = dlrnapi_client.Params3()  # Params3 | The JSON params to post
    params.job_id = options.job_id
    params.commit_hash = options.commit_hash
    params.distro_hash = options.distro_hash
    params.aggregate_hash = options.agg_hash
    params.success = str(options.success)
    params.url = options.info_url
    params.timestamp = options.timestamp
    params.notes = options.notes
    if options.extended_hash:
        params.extended_hash = options.extended_hash

    if (params.commit_hash and not params.distro_hash) or\
       (not params.commit_hash and params.distro_hash):
        raise Exception('Both --commit-hash and --distro-hash must be '
                        'specified together')

    if params.aggregate_hash and (params.commit_hash or params.distro_hash):
        raise Exception('--agg-hash is mutually exclusive with --commit-hash '
                        'and --distro-hash')

    if (not params.aggregate_hash and not params.commit_hash and
            not params.distro_hash):
        raise Exception('Must specify either --agg-hash or --commit-hash and '
                        '--distro-hash')

    try:
        api_response = api_instance.api_report_result_post(params)
        return api_response
    except ApiException as e:
        raise e


def import_commit(api_instance, options):
    params = dlrnapi_client.ModelImport()  # ModelImport | JSON params to post
    params.repo_url = options.repo_url

    try:
        api_response = api_instance.api_remote_import_post(params)
        return api_response
    except ApiException as e:
        raise e


def get_metrics_builds(api_instance, options):
    # MetricRequest | JSON params to post
    params = dlrnapi_client.MetricsRequest()
    params.start_date = options.start_date
    params.end_date = options.end_date
    if options.package_name:
        params.package_name = options.package_name

    try:
        api_response = api_instance.api_build_metrics_get(params)
        return api_response
    except ApiException as e:
        raise e


command_funcs = {
    'repo-get': get_last_tested_repo,
    'repo-use': post_last_tested_repo,
    'repo-status': repo_status,
    'agg-status': agg_status,
    'report-result': report_result,
    'repo-promote': repo_promote,
    'repo-promote-batch': repo_promote_batch,
    'commit-import': import_commit,
    'promotion-get': get_promotions,
    'build-metrics': get_metrics_builds,
}


def main():
    parser = argparse.ArgumentParser(prog='dlrnapi')

    parser.add_argument('--url',
                        required=True,
                        help='URL to use')
    parser.add_argument('--username', '-u',
                        help='username for authentication, defaults to '
                             '"DLRNAPI_USERNAME" environment variable if set',
                        default=os.getenv('DLRNAPI_USERNAME', None)
                        )
    parser.add_argument('--password', '-p',
                        help='password for authentication, defaults to '
                             '"DLRNAPI_PASSWORD" environment variable if set',
                        default=os.getenv('DLRNAPI_PASSWORD', None)
                        )

    subparsers = parser.add_subparsers(dest='command',
                                       title='subcommands',
                                       description='available subcommands')
    # Subcommand repo-get
    parser_last = subparsers.add_parser('repo-get',
                                        help='Get last tested repo')
    parser_last.add_argument('--max-age', type=int, default=0,
                             help='max_age')
    parser_last.add_argument('--success', type=str, default=None,
                             help='Find repos with a successful/unsuccessful '
                                  'vote, if true or false are specified')
    parser_last.add_argument('--job-id', type=str, default=None,
                             help='Name of the CI that sent the vote. If not '
                                  'set, no filter will be set on CI')
    parser_last.add_argument('--sequential-mode', dest='sequential',
                             action='store_true',
                             help='Use the sequential mode algorithm. In this '
                                  'case, return the last tested repo within '
                                  'that timeframe for the CI job described by '
                                  '--previous-job-id')
    parser_last.set_defaults(sequential=False)

    parser_last.add_argument('--previous-job-id', type=str, default=None,
                             help='If --sequential-mode is set, look for jobs'
                                  ' tested by this CI')
    parser_last.add_argument('--component', type=str, default=None,
                             required=False,
                             help='Only search for repos related to '
                                  'this component.')

    # Subcommand repo-use
    parser_use_last = subparsers.add_parser('repo-use',
                                            help='Get the last tested repo '
                                                 'since a specific time '
                                                 '(optionally for a CI job), '
                                                 'and add an "in progress" '
                                                 'entry in the CI job table '
                                                 'for this.')
    parser_use_last.add_argument('--max-age', type=int, default=0,
                                 help='max_age')
    parser_use_last.add_argument('--reporting-job-id', type=str, required=True,
                                 help=' Name of the CI that will add the "in '
                                      'progress" entry in the CI job table.')
    parser_use_last.add_argument('--success', type=str, default=None,
                                 help='Find repos with a successful/'
                                      'unsuccessful vote, if true or false '
                                      'are specified')
    parser_use_last.add_argument('--job-id', type=str, default=None,
                                 help='Name of the CI that sent the vote. If '
                                      'not set, no filter will be set on CI')
    parser_use_last.add_argument('--sequential-mode', dest='sequential',
                                 action='store_true',
                                 help='Use the sequential mode algorithm. In '
                                      'this case, return the last tested repo '
                                      'within that timeframe for the CI job '
                                      'described by --previous-job-id')
    parser_use_last.set_defaults(sequential=False)
    parser_use_last.add_argument('--previous-job-id', type=str, default=None,
                                 help='If --sequential-mode is true, look for '
                                      'jobs tested by this CI')
    parser_use_last.add_argument('--component', type=str, default=None,
                                 required=False,
                                 help='Only search for repos related to '
                                      'this component.')

    # Subcommand repo-status
    parser_st = subparsers.add_parser('repo-status',
                                      help='Get all the CI reports for a '
                                           'specific repository.')
    parser_st.add_argument('--commit-hash', type=str, required=True,
                           help='commit_hash of the repo to fetch '
                                'information for.')
    parser_st.add_argument('--distro-hash', type=str, required=True,
                           help='distro_hash of the repo to fetch '
                                'information for.')
    parser_st.add_argument('--extended-hash', type=str, required=False,
                           help='extended_hash of the repo to fetch '
                                'information for.')
    parser_st.add_argument('--success', type=str, default=None,
                           help='If set to a value (true/false), only return '
                                'the CI reports with the specified vote. If '
                                'not set, return all CI reports.')

    # Subcommand agg-status
    parser_st = subparsers.add_parser('agg-status',
                                      help='Get all the CI reports for a '
                                           'specific aggregated repository.')
    parser_st.add_argument('--agg-hash', type=str, required=True,
                           help='hash of the aggregated repo to fetch '
                                'information for.')
    parser_st.add_argument('--success', type=str, default=None,
                           help='If set to a value (true/false), only return '
                                'the CI reports with the specified vote. If '
                                'not set, return all CI reports.')

    # Subcommand report-result
    parser_rep = subparsers.add_parser('report-result',
                                       help='Report the result of a CI job')
    parser_rep.add_argument('--job-id', type=str, required=True,
                            help='Name of the CI sending the vote')
    parser_rep.add_argument('--commit-hash', type=str, required=False,
                            help='commit_hash of tested repo')
    parser_rep.add_argument('--distro-hash', type=str, required=False,
                            help='distro_hash of tested repo')
    parser_rep.add_argument('--extended-hash', type=str, required=False,
                            help='extended_hash of tested repo')
    parser_rep.add_argument('--agg-hash', type=str, required=False,
                            help='hash of the tested aggregated repo. Note '
                            'that either --commit-hash and --distro-hash or'
                            ' --agg-hash must be specified.')
    parser_rep.add_argument('--info-url', type=str, required=True,
                            help='URL where to find additional information '
                                 'from the CI execution')
    parser_rep.add_argument('--timestamp', type=str, required=True,
                            help='Timestamp (in seconds since the epoch)')
    parser_rep.add_argument('--success', type=str, required=True,
                            help='Was the CI execution successful? Set to '
                                 'true or false.')
    parser_rep.add_argument('--notes', type=str,
                            help='Additional notes')

    # Subcommand promote
    parser_prom = subparsers.add_parser('repo-promote',
                                        help='Promote a repository')
    parser_prom.add_argument('--commit-hash', type=str, required=True,
                             help='commit_hash of the repo to be promoted')
    parser_prom.add_argument('--distro-hash', type=str, required=True,
                             help='distro_hash of the repo to be promoted')
    parser_prom.add_argument('--extended-hash', type=str, required=False,
                             help='extended_hash of the repo to be promoted')
    parser_prom.add_argument('--promote-name', type=str, required=True,
                             help='Name to be used for the promotion')

    # Subcommand repo-promote-batch
    parser_prom = subparsers.add_parser('repo-promote-batch',
                                        help='Promote multiple repositories '
                                             'at the same time, as an atomic '
                                             'operation.')
    parser_prom.add_argument('--hash-pairs', type=str, required=True,
                             help='commit_hash+distro_hash or '
                                  'commit_hash+distro_hash+extended_hash of '
                                  'the repos to be promoted, specified as a '
                                  'comma-separated list of commit_distro or '
                                  'commit_distro_extended hash groups. If no '
                                  'extended hash is included, the latest '
                                  'commit matching the commit and distro '
                                  'hashes will be promoted.')
    parser_prom.add_argument('--promote-name', type=str, required=True,
                             help='Name to be used for the promotion')

    # Subcommand promotion-get
    parser_promget = subparsers.add_parser('promotion-get',
                                           help='Get information about '
                                                'promotions')
    parser_promget.add_argument('--commit-hash', type=str, required=False,
                                help='commit_hash of the repo to search '
                                     'promotions for. Requires --distro-hash '
                                     'if specified.')
    parser_promget.add_argument('--distro-hash', type=str, required=False,
                                help='distro_hash of the repo to search '
                                     'promotions for. Requires --commit-hash '
                                     'if specified.')
    parser_promget.add_argument('--extended-hash', type=str, required=False,
                                help='extended_hash of the repo to search '
                                     'promotions for. Requires --commit-hash '
                                     'and --distro-hash if specified.')
    parser_promget.add_argument('--agg-hash', type=str, required=False,
                                help='hash of the tested aggregated repo.')
    parser_promget.add_argument('--promote-name', type=str, required=False,
                                help='Filter results for this promotion name.')
    parser_promget.add_argument('--offset', type=int, required=False,
                                help='Show results after this offset. Each '
                                     'query will only return 100 entries by '
                                     'default.')
    parser_promget.add_argument('--limit', type=int, required=False,
                                help='Limit the results to the first limit '
                                     'items')
    parser_promget.add_argument('--component', type=str, required=False,
                                help='Only search for promotions related to '
                                     'this component.')

    # Subcommand commit-import
    parser_imp = subparsers.add_parser('commit-import',
                                       help='Import a commit built by another'
                                            ' instance')
    parser_imp.add_argument('--repo-url', type=str, required=True,
                            help='Base repository URL for the remote repo '
                                 'to import')

    # Subcommand build-metrics
    parser_metrics = subparsers.add_parser(
        'build-metrics',
        help='Fetch build metrics in a time period')
    parser_metrics.add_argument(
        '--start-date', type=str, required=True,
        help='Start date for the query, in YYYY-MM-DD format')
    parser_metrics.add_argument(
        '--end-date', type=str, required=True,
        help='End date for the query, in YYYY-MM-DD format')
    parser_metrics.add_argument(
        '--package-name', type=str, required=False,
        help='If specified, only fetch metrics for this package name')

    options, args = parser.parse_known_args(sys.argv[1:])

    # create an instance of the API class
    api_client = dlrnapi_client.ApiClient(host=options.url)
    dlrnapi_client.configuration.username = options.username
    dlrnapi_client.configuration.password = options.password
    api_instance = dlrnapi_client.DefaultApi(api_client=api_client)

    try:
        api_response = command_funcs[options.command](api_instance, options)
        print(json.dumps(api_response, cls=ResponseEncoder, indent=2,
                         sort_keys=True))
    except ApiException as e:
        # Handle 404 exceptions gracefully
        if e.status == 404:
            print("ERROR: Got error 404, probably endpoint %s is not available"
                  % options.url)
            return 1
        else:
            raise
    except Exception as e:
        raise e



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems


class Params1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    def __init__(self, max_age=None, reporting_job_id=None, success=None,
                 job_id=None, sequential_mode=None, previous_job_id=None,
                 component=None):
        """Params1 - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'max_age': 'int',
            'reporting_job_id': 'str',
            'success': 'bool',
            'job_id': 'str',
            'sequential_mode': 'bool',
            'previous_job_id': 'str',
            'component': 'str'
        }

        self.attribute_map = {
            'max_age': 'max_age',
            'reporting_job_id': 'reporting_job_id',
            'success': 'success',
            'job_id': 'job_id',
            'sequential_mode': 'sequential_mode',
            'previous_job_id': 'previous_job_id',
            'component': 'component'
        }

        self._max_age = max_age
        self._reporting_job_id = reporting_job_id
        self._success = success
        self._job_id = job_id
        self._sequential_mode = sequential_mode
        self._previous_job_id = previous_job_id
        self._component = component

    @property
    def max_age(self):
        """Gets the max_age of this Params1.

        Maximum age (in hours) for the repo to be considered.
        Any repo tested or being tested after \"now - max_age\" will be taken
        into account. If set to 0, all repos will be considered.

        :return: The max_age of this Params1.
        :rtype: int
        """
        return self._max_age

    @max_age.setter
    def max_age(self, max_age):
        """Sets the max_age of this Params1.

        Maximum age (in hours) for the repo to be considered.
        Any repo tested or being tested after \"now - max_age\" will be taken
        into account. If set to 0, all repos will be considered.

        :param max_age: The max_age of this Params1.
        :type: int
        """
        if max_age is None:
            raise ValueError("Invalid value for `max_age`, must not be `None`")
        if max_age is not None and max_age < 0:
            raise ValueError("Invalid value for `max_age`, must be a value "
                             "greater than or equal to `0`")

        self._max_age = max_age

    @property
    def reporting_job_id(self):
        """Gets the reporting_job_id of this Params1.

        Name of the CI that will add the \"in progress\" entry in the CI job
        table.

        :return: The reporting_job_id of this Params1.
        :rtype: str
        """
        return self._reporting_job_id

    @reporting_job_id.setter
    def reporting_job_id(self, reporting_job_id):
        """Sets the reporting_job_id of this Params1.

        Name of the CI that will add the \"in progress\" entry in the CI job
        table.

        :param reporting_job_id: The reporting_job_id of this Params1.
        :type: str
        """
        if reporting_job_id is None:
            raise ValueError("Invalid value for `reporting_job_id`, must not "
                             "be `None`")

        self._reporting_job_id = reporting_job_id

    @property
    def success(self):
        """Gets the success of this Params1.

        If set to a value, find repos with a successful/unsuccessful vote
        (as specified). If not set, any tested repo will be considered.

        :return: The success of this Params1.
        :rtype: bool
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this Params1.

        If set to a value, find repos with a successful/unsuccessful vote
        (as specified). If not set, any tested repo will be considered.

        :param success: The success of this Params1.
        :type: bool
        """

        self._success = success

    @property
    def job_id(self):
        """Gets the job_id of this Params1.

        Name of the CI that sent the vote. If not set, no filter will be set
        on CI.

        :return: The job_id of this Params1.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this Params1.

        Name of the CI that sent the vote. If not set, no filter will be set
        on CI.

        :param job_id: The job_id of this Params1.
        :type: str
        """

        self._job_id = job_id

    @property
    def sequential_mode(self):
        """Gets the sequential_mode of this Params1.

        Use the sequential mode algorithm. In this case, return the last tested
        repo within that timeframe for the CI job described by previous_job_id.
        Defaults to false.

        :return: The sequential_mode of this Params1.
        :rtype: bool
        """
        return self._sequential_mode

    @sequential_mode.setter
    def sequential_mode(self, sequential_mode):
        """Sets the sequential_mode of this Params1.

        Use the sequential mode algorithm. In this case, return the last tested
        repo within that timeframe for the CI job described by previous_job_id.
        Defaults to false.

        :param sequential_mode: The sequential_mode of this Params1.
        :type: bool
        """

        self._sequential_mode = sequential_mode

    @property
    def previous_job_id(self):
        """Gets the previous_job_id of this Params1.

        If sequential_mode is set to true, look for jobs tested by the CI
        identified by previous_job_id.

        :return: The previous_job_id of this Params1.
        :rtype: str
        """
        return self._previous_job_id

    @previous_job_id.setter
    def previous_job_id(self, previous_job_id):
        """Sets the previous_job_id of this Params1.

        If sequential_mode is set to true, look for jobs tested by the CI
        identified by previous_job_id.

        :param previous_job_id: The previous_job_id of this Params1.
        :type: str
        """

        self._previous_job_id = previous_job_id

    @property
    def component(self):
        """Gets the component of this Params1.

        additional notes

        :return: The component of this Params1.
        :rtype: str
        """
        return self._component

    @component.setter
    def component(self, component):
        """Sets the component of this Params1.

        additional notes

        :param component: The component of this Params1.
        :type: str
        """

        self._component = component

    def to_dict(self):
        """Returns the model properties as a dict """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model """
        return pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint` """
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal """
        if not isinstance(other, Params1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal """
        return not self == other



# coding: utf-8

"""
    DLRN API

    DLRN API client

    OpenAPI spec version: 1.0.0

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from dlrnapi_client.models.agg_query import AggQuery # noqa
from dlrnapi_client.models.ci_vote import CIVote  # noqa
from dlrnapi_client.models.ci_agg_vote import CIAggVote  # noqa
from dlrnapi_client.models.metrics import Metrics  # noqa
from dlrnapi_client.models.metrics import MetricsRequest  # noqa
from dlrnapi_client.models.model_import import ModelImport  # noqa
from dlrnapi_client.models.params import Params  # noqa
from dlrnapi_client.models.params_1 import Params1  # noqa
from dlrnapi_client.models.params_2 import Params2  # noqa
from dlrnapi_client.models.params_3 import Params3  # noqa
from dlrnapi_client.models.promotion import Promotion  # noqa
from dlrnapi_client.models.promotion_query import PromotionQuery  # noqa
from dlrnapi_client.models.repo import Repo  # noqa
